"""
backend_statistic_chart automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_statistic_chart_data import BackendStatisticChartData
class BackendStatisticChart(BaseModel):
    labels: Optional[List[str]] = Field(default=None, alias="labels")
    data: Optional[List[BackendStatisticChartData]] = Field(default=None, alias="data")
    series: Optional[List[str]] = Field(default=None, alias="series")
    pass
