"""
backend_webhook automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_webhook_response import BackendWebhookResponse
class BackendWebhook(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    event_id: Optional[int] = Field(default=None, alias="eventId")
    user_id: Optional[int] = Field(default=None, alias="userId")
    name: Optional[str] = Field(default=None, alias="name")
    endpoint: Optional[str] = Field(default=None, alias="endpoint")
    responses: Optional[List[BackendWebhookResponse]] = Field(default=None, alias="responses")
    pass
