"""
backend_cronjob automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .common_metadata import CommonMetadata
from .backend_cronjob_error import BackendCronjobError
class BackendCronjob(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    cron: Optional[str] = Field(default=None, alias="cron")
    action: Optional[str] = Field(default=None, alias="action")
    execute_date: Optional[datetime.datetime] = Field(default=None, alias="executeDate")
    exit_code: Optional[int] = Field(default=None, alias="exitCode")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    errors: Optional[List[BackendCronjobError]] = Field(default=None, alias="errors")
    pass
