"""
system_route automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .system_route_path import SystemRoutePath
class SystemRoute(BaseModel):
    routes: Optional[SystemRoutePath] = Field(default=None, alias="routes")
    pass
