"""
CommonMessageException automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import sdkgen

from .common_message import CommonMessage

class CommonMessageException(sdkgen.KnownStatusCodeException):
    payload: CommonMessage = None

    def __init__(self, payload):
        self.payload = CommonMessage.model_validate_json(json_data=payload)

    def get_payload(self) -> CommonMessage:
        return self.payload
