"""
consumer_log automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class ConsumerLog(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    app_id: Optional[int] = Field(default=None, alias="appId")
    ip: Optional[str] = Field(default=None, alias="ip")
    user_agent: Optional[str] = Field(default=None, alias="userAgent")
    method: Optional[str] = Field(default=None, alias="method")
    path: Optional[str] = Field(default=None, alias="path")
    header: Optional[str] = Field(default=None, alias="header")
    body: Optional[str] = Field(default=None, alias="body")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    pass
