"""
backend_event automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .common_metadata import CommonMetadata
class BackendEvent(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    description: Optional[str] = Field(default=None, alias="description")
    schema_: Optional[str] = Field(default=None, alias="schema")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass
