"""
backend_connection_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_connection_index_entry import BackendConnectionIndexEntry
class BackendConnectionIndex(BaseModel):
    connections: Optional[List[BackendConnectionIndexEntry]] = Field(default=None, alias="connections")
    pass
