"""
backend_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .common_metadata import CommonMetadata
from .backend_token import BackendToken
class BackendApp(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    user_id: Optional[int] = Field(default=None, alias="userId")
    status: Optional[int] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    url: Optional[str] = Field(default=None, alias="url")
    parameters: Optional[str] = Field(default=None, alias="parameters")
    app_key: Optional[str] = Field(default=None, alias="appKey")
    app_secret: Optional[str] = Field(default=None, alias="appSecret")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    tokens: Optional[List[BackendToken]] = Field(default=None, alias="tokens")
    pass
