"""
MarketplaceMessageException automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import sdkgen

from .marketplace_message import MarketplaceMessage

class MarketplaceMessageException(sdkgen.KnownStatusCodeException):
    payload: MarketplaceMessage = None

    def __init__(self, payload):
        self.payload = MarketplaceMessage.model_validate_json(json_data=payload)

    def get_payload(self) -> MarketplaceMessage:
        return self.payload
